@@ -3,10 +3,10 @@ from datetime import datetime
 from django.db import models
 from django.contrib.auth import get_user_model
 
-from .managers import BaseModelManager
+from .managers import BasisModelManager
 
 
-class BaseModel(models.Model):
+class BasisModel(models.Model):
     deleted = models.BooleanField(default=False)
 
     created_at = models.DateTimeField(default=datetime.now(), auto_now_add=True)
@@ -15,7 +15,7 @@ class BaseModel(models.Model):
     updated_at = models.DateTimeField(default=datetime.now(), auto_now=True)
     updated_by = models.ForeignKey(get_user_model(), null=True, default=None, related_name="%(class)s_updated")
 
-    objects = BaseModelManager()
+    objects = BasisModelManager()
     all_objects = models.Manager()
 
     class Meta:
@@ -29,7 +29,7 @@ class BaseModel(models.Model):
 
             self.updated_by = kwargs['current_user']
 
-        super(BaseModel, self).save()
+        super(BasisModel, self).save()
 
     def delete(self, *args, **kwargs):
         self.deleted = True
